Learn R Programming

manystates (version 1.0.3)

manystates-package: manystates: Many Data on State and State-Like Actors in the International System

Description

Comprehensively identifying states and state-like actors is difficult. This package provides data on states and state-like entities in the international system across time. The package combines and cross-references several existing datasets consistent with the aims and functions of the manydata package. It also includes functions for identifying state references in text, and for generating fictional state names.

Arguments

Author

Maintainer: James Hollway james.hollway@graduateinstitute.ch (ORCID) (IHEID) [contributor]

Other contributors:

  • Bernhard Bieri (ORCID) (IHEID) [contributor]

  • Mylan Evrard (ORCID) (IHEID) [contributor]

  • Esther Peev (ORCID) (IHEID) [contributor]

  • Henrique Sposito (ORCID) (IHEID) [contributor]

  • Jael Tan (ORCID) (IHEID) [contributor]

See Also