Comprehensively identifying states and state-like actors is difficult. This package provides data on states and state-like entities in the international system across time. The package combines and cross-references several existing datasets consistent with the aims and functions of the manydata package. It also includes functions for identifying state references in text, and for generating fictional state names.
Maintainer: James Hollway james.hollway@graduateinstitute.ch (ORCID) (IHEID) [contributor]
Other contributors:
Useful links: